import numpy as np
from _typeshed import Incomplete
from edgeiq import bounding_box as bounding_box
from edgeiq._production_client import PRODUCTION_CLIENT as PRODUCTION_CLIENT
from edgeiq._utils import draw_text_with_background as draw_text_with_background
from edgeiq.base_service import BaseService as BaseService
from edgeiq.engine_accelerator import Engine as Engine
from edgeiq.model_config import ModelConfig as ModelConfig
from edgeiq.processing import ObjectDetectionProcessor as ObjectDetectionProcessor
from edgeiq.processing.object_detection.object_detection import PostProcessBatchT as PostProcessBatchT, PostProcessT as PostProcessT, PreProcessBatchT as PreProcessBatchT, PreProcessT as PreProcessT
from edgeiq.tools.results_serialization import to_json_serializable as to_json_serializable
from typing import Any, List, Optional, Tuple

SUPPORTED_ENGINES: Incomplete

class ObjectDetectionPrediction(bounding_box.BoundingBoxPrediction):
    def __init__(self, box: bounding_box.BoundingBox, confidence: float, label: str, index: int) -> None: ...
    def __eq__(self, other) -> bool: ...
    @property
    def label(self) -> str: ...
    @property
    def index(self) -> int: ...

class ObjectDetectionResults:
    def __init__(self, predictions: List[ObjectDetectionPrediction], duration: float, image: Optional[np.ndarray], **kwargs) -> None: ...
    def __eq__(self, other) -> bool: ...
    @property
    def duration(self) -> float: ...
    @property
    def predictions(self) -> List[ObjectDetectionPrediction]: ...
    @property
    def image(self) -> Optional[np.ndarray]: ...

RESULT_TYPE: Incomplete

class ObjectDetection(BaseService[ObjectDetectionProcessor]):
    def __init__(self, model_id: str, model_config: Optional[ModelConfig] = ..., pre_process: Optional[PreProcessT] = ..., pre_process_batch: Optional[PreProcessBatchT] = ..., post_process: Optional[PostProcessT] = ..., post_process_batch: Optional[PostProcessBatchT] = ...) -> None: ...
    def detect_objects(self, image: np.ndarray, confidence_level: float = ..., overlap_threshold: float = ...) -> ObjectDetectionResults: ...
    def detect_objects_batch(self, images: List[np.ndarray], confidence_level: float = ..., overlap_threshold: float = ...) -> List[ObjectDetectionResults]: ...
    def publish_analytics(self, results: ObjectDetectionResults, tag: Any = ...): ...

def markup_image(image: np.ndarray, predictions: List[ObjectDetectionPrediction], show_labels: bool = ..., show_confidences: bool = ..., colors: Optional[List[Tuple[int, int, int]]] = ..., line_thickness: int = ..., font_size: float = ..., font_thickness: int = ..., background_padding: int = ...) -> np.ndarray: ...
def overlay_transparent_boxes(image: np.ndarray, predictions: List[ObjectDetectionPrediction], alpha: float = ..., colors: Optional[List[Tuple[int, int, int]]] = ..., show_labels: bool = ..., show_confidences: bool = ...): ...
def blur_objects(image: np.ndarray, predictions: List[ObjectDetectionPrediction]) -> np.ndarray: ...
def filter_predictions_by_label(predictions: List[ObjectDetectionPrediction], label_list: List[str]) -> List[ObjectDetectionPrediction]: ...
def filter_predictions_by_area(predictions: List[ObjectDetectionPrediction], min_area_thresh: float) -> List[ObjectDetectionPrediction]: ...
