import numpy as np
from .zone import Zone as Zone, convert_to_zone_type as convert_to_zone_type, generate_boundary as generate_boundary, validate_dimension as validate_dimension
from edgeiq._utils import draw_text_with_background as draw_text_with_background
from edgeiq.app_config import JsonFile as JsonFile
from edgeiq.object_detection import ObjectDetectionPrediction as ObjectDetectionPrediction, ObjectDetectionResults as ObjectDetectionResults
from edgeiq.object_tracking.object_tracking import TrackingResults as TrackingResults
from typing import List, Optional, Tuple

def require_unique_zone_names(zones: List[Zone]): ...
def require_same_image_dimensions(zones: List[Zone], image_width: int, image_height: int): ...
def generate_zone_mask_and_overlay(zones: List[Zone], colors: List[Tuple[int, int, int]], alpha: float, image_width: int, image_height: int) -> Tuple[np.ndarray, np.ndarray]: ...

class ZoneList:
    def __init__(self, zones: List[Zone], image_width: int, image_height: int) -> None: ...
    @classmethod
    def from_config_file(cls, filepath: str) -> ZoneList: ...
    @property
    def zones(self) -> List[Zone]: ...
    @property
    def zone_names(self) -> List[str]: ...
    @property
    def image_width(self) -> Optional[int]: ...
    @property
    def image_height(self) -> Optional[int]: ...
    @property
    def colors(self) -> List[Tuple[int, int, int]]: ...
    @property
    def alpha(self) -> float: ...
    def update_image_dimensions(self, image_width: Optional[int] = ..., image_height: Optional[int] = ...): ...
    def get_zone_by_name(self, zone_name: str) -> Zone: ...
    def get_zones_for_prediction(self, prediction: ObjectDetectionPrediction) -> ZoneList: ...
    def get_predictions_in_zone(self, results: ObjectDetectionResults, zone_name: str) -> ObjectDetectionResults: ...
    def get_tracked_objects_in_zone(self, results: TrackingResults, zone_name: str) -> TrackingResults: ...
    def create_sub_zone_list(self, zone_names: List[str]): ...
    def markup_image_with_zones(self, image: np.ndarray, show_labels: bool = ..., show_boundaries: bool = ..., fill_zones: bool = ..., line_thickness: int = ..., font_size: float = ..., font_thickness: int = ...) -> np.ndarray: ...
